import { ProgramError } from './program-error';
export function main(program) {
    const [, , ...args] = process.argv;
    Promise.resolve()
        .then(() => program(args))
        .then(code => {
        if (typeof code !== 'number') {
            code = 0;
        }
        process.exit(code);
    }, error => {
        if (error instanceof ProgramError) {
            const message = error.message;
            if (message) {
                console.error(message);
            }
            process.exit(error.code);
        }
        else {
            console.error(error instanceof Error ? error.stack : error);
            process.exit(1);
        }
    });
}
//# sourceMappingURL=main.js.map